@@ -23,7 +23,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.25';
+$VERSION = '0.26';
 
 bootstrap UUID $VERSION;
 
@@ -226,9 +226,11 @@ Authors and/or previous maintainers:
 
 =head1 CONTRIBUTORS
 
-David E. Wheeler <dwheeler@cpan.org>
+David E. Wheeler
 
-William Faulk <wfaulk@gmail.com>
+William Faulk
+
+gregor herrmann
 
 =head1 SEE ALSO
 
